//Chromatic Thermometer sketch for the LM35, with an alarm
//around 78 to 79 degrees Fahrenheit (26 degrees Celsius)
#include <Wire.h> //Set up Comm wire library
#include <LiquidCrystal_I2C.h> //Set up LCD library with I2C
LiquidCrystal_I2C lcd(0x27, 16, 2); //16x2 display I2C address 0x27
//Establish the number of readings to average at 10
const int numReadings = 10;
float readings[numReadings]; //The readings from the analog input
int index = 0; //The index of the current reading
float total = 0; //The running total
float average = 0; //The average
int tempPin = A0;
float TempC;
float tempF;
void setup() {
  lcd.init(); //Initialize LCD and turn on backlight
  lcd.backlight();
  //Initialize serial communication with computer:
  Serial.begin(9600);
  //Initialize all the readings to 0:
  for (int thisReading = 0; thisReading < numReadings; thisReading++)
    readings[thisReading] = 0;
  analogReference(INTERNAL); //Set voltageReference = 1.1V
}
void loop() {
  total = total - readings[index]; //Subtract the last reading
  readings[index] = analogRead(tempPin); //Read from the sensor
  total = total + readings[index]; //Add the reading to the total
  //Advance to the next position in the array:
  index = index + 1;
  if (index >= numReadings) //If we're at the end of the array...
    index = 0; //...wrap around to the beginning
  average = total / numReadings; //Calculate the average temperature
  TempC = average / 9.81; //Adjust/calibrate average
  //based on empirical measurement
  tempF = (TempC * 9 / 5) + 32; //Convert to Fahrenheit

  //Set up serial readout if desired
  Serial.println();
  Serial.print("TempC ");
  Serial.println(TempC);
  Serial.print("TempF ");
  Serial.println(tempF);
  Serial.print("Average ");
  Serial.println(average);
  delay(10); //Delay in between reads for stability
  //Set up for LCD
  lcd.setCursor(0, 0);
  lcd.print("Temp ");
  lcd.setCursor(7, 0);
  lcd.print(TempC, 1);
  lcd.print((char)223); //Degree symbol see below
  lcd.print(" C");
  lcd.setCursor(0, 1);
  lcd.print("Temp ");
  lcd.setCursor(7, 1);
  lcd.print(tempF, 1); //Truncate second decimal place
  lcd.print((char)223);
  /*May need to use (char) 178 if LCD displays the greek alpha character.
    Different LCDs display different special characters*/
  lcd.print(" F");
  delay(50);
  //Beginning of conditional statements for display
  if ((tempF > 85.00 ) && (tempF < 200)) {
    //85 degrees and 200 degrees are arbitrary.
    digitalWrite(2, HIGH);
  }
  else {
    digitalWrite(2, LOW);
  }
  if ((tempF > 84) && (tempF < 85)) {
    digitalWrite(3, HIGH);
  }
  else {
    digitalWrite(3, LOW);
  }
  if ((tempF > 83.00 ) && (tempF < 84)) {
    digitalWrite(4, HIGH);
  }
  else {
    digitalWrite(4, LOW);
  }
  if ((tempF > 82) && (tempF < 83)) {
    digitalWrite(5, HIGH);
  }
  else {
    digitalWrite(5, LOW);
  }
  if ((tempF > 81.00 ) && (tempF < 82)) {
    digitalWrite(6, HIGH);
  }
  else {
    digitalWrite(6, LOW);
  }
  if ((tempF > 80) && (tempF < 81)) {
    digitalWrite(7, HIGH);
  }
  else {
    digitalWrite(7, LOW);
  }
  if ((tempF > 79.00 ) && (tempF < 80)) {
    digitalWrite(8, HIGH);
  }
  else {
    digitalWrite(8, LOW);
  }
  if ((tempF > 78) && (tempF < 79)) {
    //Code for blinking LED as an alarm
    digitalWrite(9, HIGH);
    delay(50);
    digitalWrite(9, LOW);
    delay(50);
  }
  else {
    digitalWrite(9, LOW);
  }
  if ((tempF > 77.00 ) && (tempF < 78)) {
    digitalWrite(10, HIGH);
  }
  else {
    digitalWrite(10, LOW);
  }
  if (tempF < 76) {
    digitalWrite(11, HIGH);
  }
  else {
    digitalWrite(11, LOW);
  }
}
