/*Sketch for MCP9808 version of Chromatic Thermometer
  This version of the Chromatic Thermometer uses the Adafruit MCP9808 breakout
  Board (or Microchip MCP9808 chip) and the Adafruit_MCP9808 library
  available from Adafruit ----> https://www.adafruit.com/product/1782
  The averaging may not be necessary. It tends to slow the
  response a little, but smoothes out the display.
  The result is truncated to a single decimal for both Celsius and Fahrenheit.
  This version includes the code to turn on and off 10 LEDs.
*/
#include <Wire.h> //Set up wire/serial library
#include "Adafruit_MCP9808.h" //Set up MCP9808 library
#include <LiquidCrystal_I2C.h> //Set up library for LCD
LiquidCrystal_I2C lcd(0x27, 16, 2); //16x2 display; define LCD
// Create the MCP9808 temperature sensor object
Adafruit_MCP9808 tempsensor = Adafruit_MCP9808();
const int numReadings = 10; //Once again averaging 10 readings
float readings[numReadings]; //The readings from the analog input
int index = 0; //The index of the current reading
float TempC = 0;
float tempF = 0;
float total = 0; //The running total
float average = 0; //The average
void setup() {
  Serial.begin(9600);
  lcd.init(); //Initiate LCD and backlight
  lcd.backlight();
  /*Make sure the sensor is found. You can also pass a different I2C address
    from the default, as in tempsensor.begin(0x19).*/
  if (!tempsensor.begin()) {
    Serial.println("Couldn't find MCP9808!");
    while (1);
  }
}
void loop() {
  //Read and print out the temperature; then convert to Fahrenheit
  float c = tempsensor.readTempC();
  total = total - readings[index];
  //Read from the sensor
  readings[index] = c;
  //Add the reading to the total
  total = total + readings[index];
  //Advance to the next position in the array
  index = index + 1;
  if (index >= numReadings) //If we're at the end of the array...
    index = 0; //...wrap around to the beginning:
  //Calculate the average
  average = total / numReadings;
  TempC = average;
  tempF = (TempC * 9 / 5) + 32;
  delay(100);
  //Set up LCD to print out temperatures
  lcd.setCursor(0, 0);
  lcd.print("Temp ");
  lcd.setCursor(6, 0);
  lcd.print(TempC, 1); //Truncate to one decimal place
  lcd.print((char)223);
  lcd.print(" C");
  lcd.setCursor(0, 1);
  lcd.print("Temp ");
  lcd.setCursor(6, 1);
  lcd.print(tempF, 1); //Truncate to one decimal place
  lcd.print((char)223);
  /*May need to use (char) 178 if LCD displays the greek alpha character.
    Different LCDs display different special characters*/
  lcd.print(" F");
  delay(100);
  //Beginning of conditional statements for display
  if ((tempF > 85.00 ) && (tempF < 100)) {
    digitalWrite(2, HIGH);
  }
  else {
    digitalWrite(2, LOW);
  }
  if ((tempF > 84) && (tempF < 85)) {
    digitalWrite(3, HIGH);
  }
  else {
    digitalWrite(3, LOW);
  }
  if ((tempF > 83.00 ) && (tempF < 84)) {
    digitalWrite(4, HIGH);
  }
  else {
    digitalWrite(4, LOW);
  }
  if ((tempF > 82) && (tempF < 83)) {
    digitalWrite(5, HIGH);
  }
  else {
    digitalWrite(5, LOW);
  }
  if ((tempF > 81.00 ) && (tempF < 82)) {
    digitalWrite(6, HIGH);
  }
  else {
    digitalWrite(6, LOW);
  }
  if ((tempF > 80) && (tempF < 81)) {
    digitalWrite(7, HIGH);
  }
  else {
    digitalWrite(7, LOW);
  }
  if ((tempF > 79.00 ) && (tempF < 80)) {
    digitalWrite(8, HIGH);
  }
  else {
    digitalWrite(8, LOW);
  }
  if ((tempF > 78) && (tempF < 79)) { //Code for blinking LED
    digitalWrite(9, HIGH);
    delay(50);
    digitalWrite(9, LOW);
    delay(50);
  }
  else {
    digitalWrite(9, LOW);
  }
  if ((tempF > 77.00 ) && (tempF < 78)) {
    digitalWrite(10, HIGH);
  }
  else {
    digitalWrite(10, LOW);
  }
  if (tempF < 76) {
    digitalWrite(11, HIGH);
  }
  else {
    digitalWrite(11, LOW);
  }
}
